@@ -137,6 +137,13 @@ abstract class AbstractBaselinePlugin
      */
     protected String comparisonVersion;
 
+    /**
+     * Classifier for the artifact to compare the current code against.
+     *
+     * @parameter expression="${comparisonClassifier}"
+     */
+    protected String comparisonClassifier;
+
     /**
      * A list of packages filter, if empty the whole bundle will be traversed. Values are specified in OSGi package
      * instructions notation, e.g. <code>!org.apache.felix.bundleplugin</code>.
@@ -336,7 +343,7 @@ abstract class AbstractBaselinePlugin
             }
         }
 
-        getLog().info( String.format( "Baseline analisys complete, %s error(s), %s warning(s)",
+        getLog().info( String.format( "Baseline analysis complete, %s error(s), %s warning(s)",
                                       reporter.getErrors().size(),
                                       reporter.getWarnings().size() ) );
 
@@ -449,7 +456,7 @@ abstract class AbstractBaselinePlugin
                                                   project.getArtifactId(),
                                                   range,
                                                   project.getPackaging(),
-                                                  null,
+                                                  comparisonClassifier,
                                                   Artifact.SCOPE_COMPILE );
 
             if ( !previousArtifact.getVersionRange().isSelectedVersionKnown( previousArtifact ) )
@@ -550,7 +557,7 @@ abstract class AbstractBaselinePlugin
             extension = "jar"; // just in case maven gets confused
         }
 
-        String classifier = project.getArtifact().getClassifier();
+        String classifier = this.comparisonClassifier != null ? this.comparisonClassifier : project.getArtifact().getClassifier();
         if ( null != classifier && classifier.trim().length() > 0 )
         {
             return finalName + '-' + classifier + '.' + extension;
